# Anomaly-detection-in-timeseries
This is the main repository I will use to save progress in my bachelor's thesis at CTU FEE Prague.

To run demos run Jupyter notebook file "jupitest.ipynb" in "python_rewrite" folder.

08.11.2023 - This repo was created - original version with wrong multidimensional computation (distance by each dimension)

10.11.2023 - Published fixed version of multidimensional computation of dtw on Github
